# coding: utf-8

"""
    Xero Files API

    These endpoints are specific to Xero Files API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from enum import Enum


class ObjectType(Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    allowed enum values
    """

    UNKNOWN = "Unknown"
    ACCPAY = "Accpay"
    ACCPAYCREDIT = "AccPayCredit"
    ACCPAYPAYMENT = "AccPayPayment"
    ACCREC = "AccRec"
    ACCRECCREDIT = "AccRecCredit"
    ACCRECPAYMENT = "AccRecPayment"
    ADJUSTMENT = "Adjustment"
    APCREDITPAYMENT = "ApCreditPayment"
    APOVERPAYMENT = "ApOverPayment"
    APOVERPAYMENTPAYMENT = "ApOverPaymentPayment"
    APOVERPAYMENTSOURCEPAYMENT = "ApOverPaymentSourcePayment"
    APPREPAYMENT = "ApPrepayment"
    APPREPAYMENTPAYMENT = "ApPrepaymentPayment"
    APPREPAYMENTSOURCEPAYMENT = "ApPrepaymentSourcePayment"
    ARCREDITPAYMENT = "ArCreditPayment"
    AROVERPAYMENT = "ArOverPayment"
    AROVERPAYMENTPAYMENT = "ArOverpaymentPayment"
    AROVERPAYMENTSOURCEPAYMENT = "ArOverpaymentSourcePayment"
    ARPREPAYMENT = "ArPrepayment"
    ARPREPAYMENTPAYMENT = "ArPrepaymentPayment"
    ARPREPAYMENTSOURCEPAYMENT = "ArPrepaymentSourcePayment"
    CASHPAID = "CashPaid"
    CASHREC = "CashRec"
    EXPPAYMENT = "ExpPayment"
    MANJOURNAL = "ManJournal"
    PURCHASEORDER = "PurchaseOrder"
    RECEIPT = "Receipt"
    TRANSFER = "Transfer"
    ACCOUNT = "Account"
    CONTACT = "Contact"
    BUSINESS = "Business"
    EMPLOYEE = "Employee"
    PERSON = "Person"
    USER = "User"
    ORG = "Org"
    FIXEDASSET = "FixedAsset"
    PAYRUN = "PayRun"
    PRICELISTITEM = "PriceListItem"
    BANK = "Bank"
    CURRENT = "Current"
    EQUITY = "Equity"
    EXPENSE = "Expense"
    FIXED = "Fixed"
    LIABILITY = "Liability"
    PREPAYMENT = "Prepayment"
    REVENUE = "Revenue"
    SALES = "Sales"
    OVERHEADS = "Overheads"
    DEPRECIATN = "Depreciatn"
    OTHERINCOME = "OtherIncome"
    DIRECTCOSTS = "DirectCosts"
    CURRLIAB = "Currliab"
    TERMLIAB = "Termliab"
    NONCURRENT = "NonCurrent"
