# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TrackingCategory(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "employee_groups_tracking_category_id": "str",
        "timesheet_tracking_category_id": "str",
    }

    attribute_map = {
        "employee_groups_tracking_category_id": "employeeGroupsTrackingCategoryID",
        "timesheet_tracking_category_id": "timesheetTrackingCategoryID",
    }

    def __init__(
        self,
        employee_groups_tracking_category_id=None,
        timesheet_tracking_category_id=None,
    ):  # noqa: E501
        """TrackingCategory - a model defined in OpenAPI"""  # noqa: E501

        self._employee_groups_tracking_category_id = None
        self._timesheet_tracking_category_id = None
        self.discriminator = None

        if employee_groups_tracking_category_id is not None:
            self.employee_groups_tracking_category_id = (
                employee_groups_tracking_category_id
            )
        if timesheet_tracking_category_id is not None:
            self.timesheet_tracking_category_id = timesheet_tracking_category_id

    @property
    def employee_groups_tracking_category_id(self):
        """Gets the employee_groups_tracking_category_id of this TrackingCategory.  # noqa: E501

        The Xero identifier for Employee groups tracking category.  # noqa: E501

        :return: The employee_groups_tracking_category_id of this TrackingCategory.  # noqa: E501
        :rtype: str
        """
        return self._employee_groups_tracking_category_id

    @employee_groups_tracking_category_id.setter
    def employee_groups_tracking_category_id(
        self, employee_groups_tracking_category_id
    ):
        """Sets the employee_groups_tracking_category_id of this TrackingCategory.

        The Xero identifier for Employee groups tracking category.  # noqa: E501

        :param employee_groups_tracking_category_id: The employee_groups_tracking_category_id of this TrackingCategory.  # noqa: E501
        :type: str
        """

        self._employee_groups_tracking_category_id = (
            employee_groups_tracking_category_id
        )

    @property
    def timesheet_tracking_category_id(self):
        """Gets the timesheet_tracking_category_id of this TrackingCategory.  # noqa: E501

        The Xero identifier for Timesheet tracking category.  # noqa: E501

        :return: The timesheet_tracking_category_id of this TrackingCategory.  # noqa: E501
        :rtype: str
        """
        return self._timesheet_tracking_category_id

    @timesheet_tracking_category_id.setter
    def timesheet_tracking_category_id(self, timesheet_tracking_category_id):
        """Sets the timesheet_tracking_category_id of this TrackingCategory.

        The Xero identifier for Timesheet tracking category.  # noqa: E501

        :param timesheet_tracking_category_id: The timesheet_tracking_category_id of this TrackingCategory.  # noqa: E501
        :type: str
        """

        self._timesheet_tracking_category_id = timesheet_tracking_category_id
