# coding: utf-8

# flake8: noqa

"""
    Xero Assets API

    The Assets API exposes fixed asset related functions of the Xero Accounting application and can be used for a variety of purposes such as creating assets, retrieving asset valuations etc.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


# import apis into sdk package
from xero_python.assets.api.asset_api import AssetApi


# import models into sdk package
from xero_python.assets.models.asset import Asset
from xero_python.assets.models.asset_status import AssetStatus
from xero_python.assets.models.asset_status_query_param import AssetStatusQueryParam
from xero_python.assets.models.asset_type import AssetType
from xero_python.assets.models.assets import Assets
from xero_python.assets.models.book_depreciation_detail import BookDepreciationDetail
from xero_python.assets.models.book_depreciation_setting import BookDepreciationSetting
from xero_python.assets.models.error import Error
from xero_python.assets.models.field_validation_errors_element import (
    FieldValidationErrorsElement,
)
from xero_python.assets.models.pagination import Pagination
from xero_python.assets.models.resource_validation_errors_element import (
    ResourceValidationErrorsElement,
)
from xero_python.assets.models.setting import Setting
