# coding: utf-8

"""
    Xero Files API

    These endpoints are specific to Xero Files API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Folders(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"folders": "list[Folder]"}

    attribute_map = {"folders": "Folders"}

    def __init__(self, folders=None):  # noqa: E501
        """Folders - a model defined in OpenAPI"""  # noqa: E501

        self._folders = None
        self.discriminator = None

        if folders is not None:
            self.folders = folders

    @property
    def folders(self):
        """Gets the folders of this Folders.  # noqa: E501


        :return: The folders of this Folders.  # noqa: E501
        :rtype: list[Folder]
        """
        return self._folders

    @folders.setter
    def folders(self, folders):
        """Sets the folders of this Folders.


        :param folders: The folders of this Folders.  # noqa: E501
        :type: list[Folder]
        """

        self._folders = folders
